@@ -1,6 +1,8 @@
 # coding=utf-8
 from django.contrib.auth.models import User
 from django.db import models
+from django.utils import unittest
+from django.template import Template, Context
 import fudge
 try:
     import south
@@ -18,7 +20,7 @@ from .._utils import *
 from ...fields import authors
 
 
-class AuthorsFieldTestCase(TestCase):
+class AuthorsFieldTestCase(ArmContentTestCase):
     def test_authors_can_have_one_author(self):
         [bob, ] = generate_random_staff_users(n=1)
         article = SimpleAuthoredModel.objects.create()
@@ -166,8 +168,7 @@ class AuthorsFieldTestCase(TestCase):
                 "override_field_name": "'authors_override'",
                 "extra_field_name": "'authors_extra'",
                 "symmetrical": "False",
-            }
-        )
+            })
         self.assertEqual(field.south_field_triple(), expected)
 
     def test_defaults_to_being_related_to_base_user(self):
@@ -181,8 +182,17 @@ class AuthorsFieldTestCase(TestCase):
         field = authors.AuthorsField(to=MyUser)
         self.assertEqual(field.rel.to, MyUser)
 
+    def test_can_render_in_templates(self):
+        [bob, ] = generate_random_staff_users(n=1)
+        article = SimpleAuthoredModel.objects.create()
+        article.authors.add(bob)
+        t = Template("{{ article.authors }}")
+        context = Context({"article": article})
+        self.assertEqual(bob.get_full_name(), t.render(context))
 
-class AuthorsDescriptorTestCase(TestCase):
+
+
+class AuthorsDescriptorTestCase(ArmContentTestCase):
     def test_does_not_choke_on_empty_instance(self):
         try:
             authors_field = SimpleAuthoredModel.authors
